@@ -132,7 +132,7 @@ class AudiocodesInput(InputChannel):
 
     def _check_token(self, token: Optional[Text]) -> None:
         if not token or not token.replace("Bearer ", "") == self.token:
-            sanic.exceptions.abort(401)
+            raise sanic.SanicException(status_code=401)
 
     def _get_conversation(
         self, token: Optional["Text"], cid: Text
@@ -140,8 +140,7 @@ class AudiocodesInput(InputChannel):
         self._check_token(token)
         conversation = self.conversations.get(cid)
         if not conversation:
-            sanic.exceptions.abort(404, "Not found")
-            return None
+            raise sanic.SanicException("Not found", status_code=404)
         conversation.update()
         return conversation
 
@@ -158,7 +157,7 @@ class AudiocodesInput(InputChannel):
     def handle_start_conversation(self, body: Dict[Text, Any]) -> Dict[Text, Any]:
         cid = body["conversation"]
         if cid in self.conversations:
-            sanic.exceptions.abort(500, "Conversation already exists")
+            raise sanic.SanicException("Conversation already exists", status_code=500)
         logger.debug(f"(handle_start_conversation) --- New Conversation has arrived. Conversation: {cid}")
         self.conversations[cid] = AudiocodesInput.Conversation(cid)
         urls = {
